@@ -25,18 +25,7 @@ DEALINGS IN THE SOFTWARE.
 
 from __future__ import annotations
 
-from typing import (
-    TYPE_CHECKING,
-    Any,
-    ClassVar,
-    Dict,
-    List,
-    Optional,
-    Tuple,
-    Type,
-    TypeVar,
-    Union,
-)
+from typing import TYPE_CHECKING, Any, ClassVar, TypeVar
 
 from .enums import ButtonStyle, ComponentType, InputTextStyle, try_enum
 from .partial_emoji import PartialEmoji, _EmojiTag
@@ -78,14 +67,14 @@ class Component:
     .. versionadded:: 2.0
 
     Attributes
-    ------------
+    ----------
     type: :class:`ComponentType`
         The type of component.
     """
 
-    __slots__: Tuple[str, ...] = ("type",)
+    __slots__: tuple[str, ...] = ("type",)
 
-    __repr_info__: ClassVar[Tuple[str, ...]]
+    __repr_info__: ClassVar[tuple[str, ...]]
     type: ComponentType
 
     def __repr__(self) -> str:
@@ -93,7 +82,7 @@ class Component:
         return f"<{self.__class__.__name__} {attrs}>"
 
     @classmethod
-    def _raw_construct(cls: Type[C], **kwargs) -> C:
+    def _raw_construct(cls: type[C], **kwargs) -> C:
         self: C = cls.__new__(cls)
         for slot in get_slots(cls):
             try:
@@ -104,7 +93,7 @@ class Component:
                 setattr(self, slot, value)
         return self
 
-    def to_dict(self) -> Dict[str, Any]:
+    def to_dict(self) -> dict[str, Any]:
         raise NotImplementedError
 
 
@@ -118,20 +107,22 @@ class ActionRow(Component):
     .. versionadded:: 2.0
 
     Attributes
-    ------------
+    ----------
     type: :class:`ComponentType`
         The type of component.
     children: List[:class:`Component`]
         The children components that this holds, if any.
     """
 
-    __slots__: Tuple[str, ...] = ("children",)
+    __slots__: tuple[str, ...] = ("children",)
 
-    __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
+    __repr_info__: ClassVar[tuple[str, ...]] = __slots__
 
     def __init__(self, data: ComponentPayload):
         self.type: ComponentType = try_enum(ComponentType, data["type"])
-        self.children: List[Component] = [_component_factory(d) for d in data.get("components", [])]
+        self.children: list[Component] = [
+            _component_factory(d) for d in data.get("components", [])
+        ]
 
     def to_dict(self) -> ActionRowPayload:
         return {
@@ -143,6 +134,7 @@ class ActionRow(Component):
 class InputText(Component):
     """Represents an Input Text field from the Discord Bot UI Kit.
     This inherits from :class:`Component`.
+
     Attributes
     ----------
     style: :class:`.InputTextStyle`
@@ -164,7 +156,7 @@ class InputText(Component):
         The value that has been entered in the input text field.
     """
 
-    __slots__: Tuple[str, ...] = (
+    __slots__: tuple[str, ...] = (
         "type",
         "style",
         "custom_id",
@@ -176,18 +168,18 @@ class InputText(Component):
         "value",
     )
 
-    __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
+    __repr_info__: ClassVar[tuple[str, ...]] = __slots__
 
     def __init__(self, data: InputTextComponentPayload):
         self.type = ComponentType.input_text
         self.style: InputTextStyle = try_enum(InputTextStyle, data["style"])
         self.custom_id = data["custom_id"]
         self.label: str = data.get("label", None)
-        self.placeholder: Optional[str] = data.get("placeholder", None)
-        self.min_length: Optional[int] = data.get("min_length", None)
-        self.max_length: Optional[int] = data.get("max_length", None)
+        self.placeholder: str | None = data.get("placeholder", None)
+        self.min_length: int | None = data.get("min_length", None)
+        self.max_length: int | None = data.get("max_length", None)
         self.required: bool = data.get("required", True)
-        self.value: Optional[str] = data.get("value", None)
+        self.value: str | None = data.get("value", None)
 
     def to_dict(self) -> InputTextComponentPayload:
         payload = {
@@ -229,7 +221,7 @@ class Button(Component):
     .. versionadded:: 2.0
 
     Attributes
-    -----------
+    ----------
     style: :class:`.ButtonStyle`
         The style of the button.
     custom_id: Optional[:class:`str`]
@@ -245,7 +237,7 @@ class Button(Component):
         The emoji of the button, if available.
     """
 
-    __slots__: Tuple[str, ...] = (
+    __slots__: tuple[str, ...] = (
         "style",
         "custom_id",
         "url",
@@ -254,16 +246,16 @@ class Button(Component):
         "emoji",
     )
 
-    __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
+    __repr_info__: ClassVar[tuple[str, ...]] = __slots__
 
     def __init__(self, data: ButtonComponentPayload):
         self.type: ComponentType = try_enum(ComponentType, data["type"])
         self.style: ButtonStyle = try_enum(ButtonStyle, data["style"])
-        self.custom_id: Optional[str] = data.get("custom_id")
-        self.url: Optional[str] = data.get("url")
+        self.custom_id: str | None = data.get("custom_id")
+        self.url: str | None = data.get("url")
         self.disabled: bool = data.get("disabled", False)
-        self.label: Optional[str] = data.get("label")
-        self.emoji: Optional[PartialEmoji]
+        self.label: str | None = data.get("label")
+        self.emoji: PartialEmoji | None
         try:
             self.emoji = PartialEmoji.from_dict(data["emoji"])
         except KeyError:
@@ -302,14 +294,14 @@ class SelectMenu(Component):
     .. versionadded:: 2.0
 
     Attributes
-    ------------
+    ----------
     custom_id: Optional[:class:`str`]
         The ID of the select menu that gets received during an interaction.
     placeholder: Optional[:class:`str`]
         The placeholder text that is shown if nothing is selected, if any.
     min_values: :class:`int`
         The minimum number of items that must be chosen for this select menu.
-        Defaults to 1 and must be between 1 and 25.
+        Defaults to 1 and must be between 0 and 25.
     max_values: :class:`int`
         The maximum number of items that must be chosen for this select menu.
         Defaults to 1 and must be between 1 and 25.
@@ -319,7 +311,7 @@ class SelectMenu(Component):
         Whether the select is disabled or not.
     """
 
-    __slots__: Tuple[str, ...] = (
+    __slots__: tuple[str, ...] = (
         "custom_id",
         "placeholder",
         "min_values",
@@ -328,15 +320,17 @@ class SelectMenu(Component):
         "disabled",
     )
 
-    __repr_info__: ClassVar[Tuple[str, ...]] = __slots__
+    __repr_info__: ClassVar[tuple[str, ...]] = __slots__
 
     def __init__(self, data: SelectMenuPayload):
         self.type = ComponentType.select
         self.custom_id: str = data["custom_id"]
-        self.placeholder: Optional[str] = data.get("placeholder")
+        self.placeholder: str | None = data.get("placeholder")
         self.min_values: int = data.get("min_values", 1)
         self.max_values: int = data.get("max_values", 1)
-        self.options: List[SelectOption] = [SelectOption.from_dict(option) for option in data.get("options", [])]
+        self.options: list[SelectOption] = [
+            SelectOption.from_dict(option) for option in data.get("options", [])
+        ]
         self.disabled: bool = data.get("disabled", False)
 
     def to_dict(self) -> SelectMenuPayload:
@@ -363,7 +357,7 @@ class SelectOption:
     .. versionadded:: 2.0
 
     Attributes
-    -----------
+    ----------
     label: :class:`str`
         The label of the option. This is displayed to users.
         Can only be up to 100 characters.
@@ -374,17 +368,15 @@ class SelectOption:
     description: Optional[:class:`str`]
         An additional description of the option, if any.
         Can only be up to 100 characters.
-    emoji: Optional[Union[:class:`str`, :class:`Emoji`, :class:`PartialEmoji`]]
-        The emoji of the option, if available.
     default: :class:`bool`
         Whether this option is selected by default.
     """
 
-    __slots__: Tuple[str, ...] = (
+    __slots__: tuple[str, ...] = (
         "label",
         "value",
         "description",
-        "emoji",
+        "_emoji",
         "default",
     )
 
@@ -393,28 +385,22 @@ class SelectOption:
         *,
         label: str,
         value: str = MISSING,
-        description: Optional[str] = None,
-        emoji: Optional[Union[str, Emoji, PartialEmoji]] = None,
+        description: str | None = None,
+        emoji: str | Emoji | PartialEmoji | None = None,
         default: bool = False,
     ) -> None:
         if len(label) > 100:
             raise ValueError("label must be 100 characters or fewer")
+
         if value is not MISSING and len(value) > 100:
             raise ValueError("value must be 100 characters or fewer")
+
         if description is not None and len(description) > 100:
             raise ValueError("description must be 100 characters or fewer")
+
         self.label = label
         self.value = label if value is MISSING else value
         self.description = description
-
-        if emoji is not None:
-            if isinstance(emoji, str):
-                emoji = PartialEmoji.from_str(emoji)
-            elif isinstance(emoji, _EmojiTag):
-                emoji = emoji._to_partial()
-            else:
-                raise TypeError(f"expected emoji to be str, Emoji, or PartialEmoji not {emoji.__class__}")
-
         self.emoji = emoji
         self.default = default
 
@@ -430,6 +416,25 @@ class SelectOption:
             return f"{base}\n{self.description}"
         return base
 
+    @property
+    def emoji(self) -> str | Emoji | PartialEmoji | None:
+        """Optional[Union[:class:`str`, :class:`Emoji`, :class:`PartialEmoji`]]: The emoji of the option, if available."""
+        return self._emoji
+
+    @emoji.setter
+    def emoji(self, value) -> None:
+        if value is not None:
+            if isinstance(value, str):
+                value = PartialEmoji.from_str(value)
+            elif isinstance(value, _EmojiTag):
+                value = value._to_partial()
+            else:
+                raise TypeError(
+                    f"expected emoji to be str, Emoji, or PartialEmoji not {value.__class__}"
+                )
+
+        self._emoji = value
+
     @classmethod
     def from_dict(cls, data: SelectOptionPayload) -> SelectOption:
         try:
