@@ -390,6 +390,13 @@ class TextMESSAGE(BaseMESSAGE):
                 if (member := channel.guild.get_member(client_.user.id)) is None:
                     raise self._generate_exception(404, -1, "Client user could not be found in guild members", discord.NotFound)
 
+                if channel.guild.me.pending:
+                    raise self._generate_exception(
+                        403, 50009,
+                        "Channel verification level is too high for you to gain access",
+                        discord.Forbidden
+                    )
+
                 ch_perms = channel.permissions_for(member)
                 if ch_perms.send_messages is False:
                     raise self._generate_exception(403, 50013, "You lack permissions to perform that action", discord.Forbidden)
